@@ -6,11 +6,11 @@ source ${WORKDIR}/common.sh
 
 IRONIC_LIB_SOURCE=${IRONIC_LIB_SOURCE:-}
 
-TC_RELEASE="13.x"
+TC_RELEASE="15.x"
 QEMU_RELEASE="v5.2.0"
 LSHW_RELEASE="B.02.18"
 BIOSDEVNAME_RELEASE="0.7.2"
-IPMITOOL_GIT_HASH="710888479332a46bad78f3d736eff0cbdefd2d1b"
+IPMITOOL_GIT_HASH="19d78782d795d0cf4ceefe655f616210c9143e62"
 
 CHROOT_CMD="sudo chroot $BUILDDIR /usr/bin/env -i PATH=$CHROOT_PATH http_proxy=$http_proxy https_proxy=$https_proxy no_proxy=$no_proxy"
 
@@ -42,7 +42,7 @@ wget -N $TINYCORE_MIRROR_URL/$TC_RELEASE/x86_64/release/distribution_files/vmlin
 cd $WORKDIR
 
 ########################################################
-# Build Required Python Dependecies in a Build Directory
+# Build Required Python Dependencies in a Build Directory
 ########################################################
 
 # Make directory for building in
@@ -61,7 +61,7 @@ if $TINYIPA_REQUIRE_BIOSDEVNAME; then
     wget -N -O - https://linux.dell.com/biosdevname/biosdevname-${BIOSDEVNAME_RELEASE}/biosdevname-${BIOSDEVNAME_RELEASE}.tar.gz | tar -xz -C "${BUILDDIR}/tmp" -f -
 fi
 if $TINYIPA_REQUIRE_IPMITOOL; then
-    git clone https://github.com/ipmitool/ipmitool.git "${BUILDDIR}/tmp/ipmitool-src"
+    git clone https://codeberg.org/IPMITool/ipmitool.git "${BUILDDIR}/tmp/ipmitool-src"
     cd "${BUILDDIR}/tmp/ipmitool-src"
     git reset $IPMITOOL_GIT_HASH --hard
     cd -
@@ -76,10 +76,7 @@ cd $IPA_SOURCE_DIR
 rm -rf *.egg-info
 pwd
 
-PYTHON_COMMAND="python"
-if [[ $USE_PYTHON3 == "True" ]]; then
-    PYTHON_COMMAND="python3"
-fi
+PYTHON_COMMAND="python3"
 $PYTHON_COMMAND setup.py sdist --dist-dir "$BUILDDIR/tmp/localpip" --quiet
 
 ls $BUILDDIR/tmp/localpip || true
@@ -145,15 +142,12 @@ $CHROOT_CMD mkdir -m777 /etc/sysconfig/tcedir
 $CHROOT_CMD touch /etc/sysconfig/tcuser
 $CHROOT_CMD chmod a+rwx /etc/sysconfig/tcuser
 
-mkdir $BUILDDIR/tmp/overides
-cp $WORKDIR/build_files/fakeuname $BUILDDIR/tmp/overides/uname
+mkdir $BUILDDIR/tmp/overrides
+cp $WORKDIR/build_files/fakeuname $BUILDDIR/tmp/overrides/uname
 
 sudo cp $WORKDIR/build_files/ntpdate $BUILDDIR/bin/ntpdate
 
-PY_REQS="buildreqs_python2.lst"
-if [[ $USE_PYTHON3 == "True" ]]; then
-    PY_REQS="buildreqs_python3.lst"
-fi
+PY_REQS="buildreqs_python3.lst"
 
 # NOTE(rpittau) change ownership of the tce info dir to prevent writing issues
 sudo chown $TC:$STAFF $BUILDDIR/usr/local/tce.installed
@@ -162,12 +156,9 @@ while read line; do
     sudo chroot --userspec=$TC:$STAFF $BUILDDIR /usr/bin/env -i PATH=$CHROOT_PATH http_proxy=$http_proxy https_proxy=$https_proxy no_proxy=$no_proxy tce-load -wci $line
 done < <(paste $WORKDIR/build_files/$PY_REQS $WORKDIR/build_files/buildreqs.lst)
 
-PIP_COMMAND="pip"
-TINYIPA_PYTHON_EXE="python"
-if [[ $USE_PYTHON3 == "True" ]]; then
-    PIP_COMMAND="pip3"
-    TINYIPA_PYTHON_EXE="python3"
-fi
+TINYIPA_PYTHON_EXE="python3.9"
+
+PIP_COMMAND="$TINYIPA_PYTHON_EXE -m pip"
 
 # Build python wheels
 $CHROOT_CMD ${TINYIPA_PYTHON_EXE} -m ensurepip
